{% extends "reviewpanel/base.html" %}
{% load static %}

{% block style %}
  <link rel="stylesheet" href="{% static "css/reviewpanel.css" %}">
{% endblock %}

{% block content %}
<div class="center-fixed">
  All done! message TODO
</div>
{% endblock %}
